pub enum CudaResidentGraphSessionEvidenceError {
Session(CudaResidentGraphSessionError),
Speedup(CudaMegakernelSpeedupGateError),
SampleReserveFailed {
capacity: usize,
message: String,
},
}Expand description
Error while converting resident graph session evidence into release CSV.
Variants
Session(CudaResidentGraphSessionError)
Resident session evidence was not a valid final-only resident session.
Speedup(CudaMegakernelSpeedupGateError)
Megakernel speedup release gate rejected the converted samples.
SampleReserveFailed
Resident session evidence sample staging could not reserve enough slots.