CudaEGraphKernelPlanError

Enum CudaEGraphKernelPlanError 

pub enum CudaEGraphKernelPlanError {
    ZeroThreadsPerBlock,
    ZeroMaxBlocksPerLaunch,
    CountOverflow {
        field: &'static str,
    },
    InvalidPtxTarget {
        target_sm: u32,
    },
    ImageViewMismatch {
        field: &'static str,
        image: usize,
        view: usize,
    },
    ImageColumnOutOfBounds {
        column: &'static str,
        row: u32,
        start: usize,
        end: usize,
        len: usize,
    },
    SignaturePairOrdinalOutOfBounds {
        bucket_index: u32,
        pair_ordinal: u64,
        candidate_pair_count: u64,
    },
    SignatureBucketRowsOutOfBounds {
        bucket_index: u32,
        first_bucket_row: usize,
        row_count: usize,
        bucket_rows_len: usize,
    },
    StorageReserveFailed {
        field: &'static str,
        requested: usize,
        message: String,
    },
}
Error returned when e-graph kernel work cannot be planned.

Variants



ZeroThreadsPerBlock

Threads per block was zero.



ZeroMaxBlocksPerLaunch

Maximum blocks per launch was zero.



CountOverflow

Count arithmetic overflowed.

Fields

field: &'static str

Field being computed.



InvalidPtxTarget

PTX generation received an invalid CUDA SM target.

Fields

target_sm: u32

Invalid sm_XX target.



ImageViewMismatch

Packed image metadata did not match the checked CUDA kernel view.

Fields

field: &'static str

Field that disagreed.

image: usize

Count from the packed foundation image.

view: usize

Count from the CUDA kernel view.



ImageColumnOutOfBounds

A packed row child span pointed outside the packed child column.

Fields

column: &'static str

Column being decoded.

row: u32

Row being decoded.

start: usize

Start index into the column.

end: usize

End index into the column.

len: usize

Column length.



SignaturePairOrdinalOutOfBounds

A pair ordinal did not identify a valid row pair in a signature bucket.

Fields

bucket_index: u32

Signature bucket being decoded.

pair_ordinal: u64

Pair ordinal inside the bucket’s triangular pair space.

candidate_pair_count: u64

Number of candidate pairs in the bucket.



SignatureBucketRowsOutOfBounds

A signature bucket’s row range pointed outside the bucket row table.

Fields

bucket_index: u32

Signature bucket being decoded.

first_bucket_row: usize

First row offset in the bucket row table.

row_count: usize

Bucket row count.

bucket_rows_len: usize

Available row table length.



StorageReserveFailed

Planner storage reservation failed.

Fields

field: &'static str

Field being reserved.

requested: usize

Requested element count.

message: String

Allocator error text.